==> FiPy-2.1.2.tar.gz: FiPy-2.1.2/fipy/variables/test.py <==
#!/usr/bin/env python

## 
 # ###################################################################
 #  FiPy - Python-based finite volume PDE solver
 # 
 #  FILE: "test.py"
 #
 #  Author: Jonathan Guyer <guyer@nist.gov>
 #  Author: Daniel Wheeler <daniel.wheeler@nist.gov>
 #  Author: James Warren   <jwarren@nist.gov>
 #    mail: NIST
 #     www: http://www.ctcms.nist.gov/fipy/
 #  
 # ========================================================================
 # This software was developed at the National Institute of Standards
 # and Technology by employees of the Federal Government in the course
 # of their official duties.  Pursuant to title 17 Section 105 of the
 # United States Code this software is not subject to copyright
 # protection and is in the public domain.  FiPy is an experimental
 # system.  NIST assumes no responsibility whatsoever for its use by
 # other parties, and makes no guarantees, expressed or implied, about
 # its quality, reliability, or any other characteristic.  We would
 # appreciate acknowledgement if the software is used.
 # 
 # This software can be redistributed and/or modified freely
 # provided that any derivative works bear some notice that they are
 # derived from it, and any modified versions bear some notice that
 # they have been modified.
 #  
 # ###################################################################
 ##

"""Test numeric implementation of the mesh
"""

from fipy.tests.doctestPlus import _LateImportDocTestSuite
import fipy.tests.testProgram

def _suite():
    return _LateImportDocTestSuite(
        docTestModuleNames = (
            'fipy.variables.variable',
            'fipy.variables.meshVariable',
            'fipy.variables.cellVariable',
            'fipy.variables.faceVariable',
            'fipy.variables.operatorVariable',
            'fipy.variables.betaNoiseVariable',
            'fipy.variables.exponentialNoiseVariable',
            'fipy.variables.gammaNoiseVariable',
            'fipy.variables.gaussianNoiseVariable',
            'fipy.variables.uniformNoiseVariable',
            'fipy.variables.cellVolumeAverageVariable',
            'fipy.variables.modularVariable',
            'fipy.variables.binaryOperatorVariable'
        ))
    
if __name__ == '__main__':
    fipy.tests.testProgram.main(defaultTest='_suite')

==> FiPy-3.0.tar.gz: FiPy-3.0/fipy/variables/test.py <==
#!/usr/bin/env python

## 
 # ###################################################################
 #  FiPy - Python-based finite volume PDE solver
 # 
 #  FILE: "test.py"
 #
 #  Author: Jonathan Guyer <guyer@nist.gov>
 #  Author: Daniel Wheeler <daniel.wheeler@nist.gov>
 #  Author: James Warren   <jwarren@nist.gov>
 #    mail: NIST
 #     www: http://www.ctcms.nist.gov/fipy/
 #  
 # ========================================================================
 # This software was developed at the National Institute of Standards
 # and Technology by employees of the Federal Government in the course
 # of their official duties.  Pursuant to title 17 Section 105 of the
 # United States Code this software is not subject to copyright
 # protection and is in the public domain.  FiPy is an experimental
 # system.  NIST assumes no responsibility whatsoever for its use by
 # other parties, and makes no guarantees, expressed or implied, about
 # its quality, reliability, or any other characteristic.  We would
 # appreciate acknowledgement if the software is used.
 # 
 # This software can be redistributed and/or modified freely
 # provided that any derivative works bear some notice that they are
 # derived from it, and any modified versions bear some notice that
 # they have been modified.
 #  
 # ###################################################################
 ##

"""Test numeric implementation of the mesh
"""

__all__ = []

from fipy.tests.doctestPlus import _LateImportDocTestSuite
import fipy.tests.testProgram

def _suite():
    return _LateImportDocTestSuite(
        docTestModuleNames = (
            'fipy.variables.variable',
            'fipy.variables.meshVariable',
            'fipy.variables.cellVariable',
            'fipy.variables.faceVariable',
            'fipy.variables.operatorVariable',
            'fipy.variables.betaNoiseVariable',
            'fipy.variables.exponentialNoiseVariable',
            'fipy.variables.gammaNoiseVariable',
            'fipy.variables.gaussianNoiseVariable',
            'fipy.variables.uniformNoiseVariable',
            'fipy.variables.cellVolumeAverageVariable',
            'fipy.variables.modularVariable',
            'fipy.variables.binaryOperatorVariable',
            'fipy.variables.coupledCellVariable',
            'fipy.variables.cellToFaceVariable',
            'fipy.variables.faceGradVariable',
            'fipy.variables.gaussCellGradVariable',
            'fipy.variables.faceGradContributionsVariable'
        ))
    
if __name__ == '__main__':
    fipy.tests.testProgram.main(defaultTest='_suite')
